import os
import tkinter as tk
from tkinter import filedialog
from os import environ
environ['PYGAME_HIDE_SUPPORT_PROMPT'] = '1'
import pygame
import pygame
import time

class MusicPlayer:
    def __init__(self, root):
        self.root = root
        self.folder_path = ""
        self.current_index = 0
        self.current_file = ""

        self.root.title("棋譜読み上げ")

        self.folder_button = tk.Button(
            self.root, text="棋譜フォルダ選択", command=self.select_folder
        )
        self.folder_button.place(x=10, y=15)

        self.prev_10_button = tk.Button(
            self.root, text="10手前[↑]", state=tk.DISABLED, command=self.play_previous_10
        )
        self.prev_10_button.place(x=10, y=55)

        self.prev_button = tk.Button(
            self.root, text="前の手[←]", state=tk.DISABLED, command=self.play_previous
        )
        self.prev_button.place(x=90, y=55)

        self.play_button = tk.Button(
            self.root, text="次の手(再生)[→]", state=tk.DISABLED, command=self.play_music
        )
        self.play_button.place(x=170, y=55)

        self.next_10_button = tk.Button(
            self.root, text="10手後[↓]", state=tk.DISABLED, command=self.play_next_10
        )
        self.next_10_button.place(x=280, y=55)

        self.replay_button = tk.Button(
            self.root, text="もう一度[スペース]", state=tk.DISABLED, command=self.play_same
        )
        self.replay_button.place(x=365, y=55)

        self.current_file_label = tk.Label(self.root, text="")
        self.current_file_label.place(x=150, y=20)

        self.folder_label = tk.Label(self.root, text="")
        self.folder_label.place(x=10, y=135)


        #<<自動再生追加部
        self.auto_play_5_button = tk.Button(
            self.root, text="自動再生(5秒)", state=tk.DISABLED, command=self.auto_play_5
        )
        self.auto_play_5_button.place(x=10, y=95)
        
        self.auto_play_10_button = tk.Button(
            self.root, text="自動再生(10秒)", state=tk.DISABLED, command=self.auto_play_10
        )
        self.auto_play_10_button.place(x=110, y=95)

        self.auto_play_15_button = tk.Button(
            self.root, text="自動再生(15秒)", state=tk.DISABLED, command=self.auto_play_15
        )
        self.auto_play_15_button.place(x=220, y=95)
        
        self.auto_play_5_flag = False
        self.auto_play_10_flag = False
        self.auto_play_15_flag = False
        #自動再生追加部>>

        self.root.bind("<Right>", self.play_button_press)
        self.root.bind("<Left>", self.prev_button_press)
        self.root.bind("<Down>", self.next_10_button_press)
        self.root.bind("<Up>", self.prev_10_button_press)
        self.root.bind("<space>", self.replay_button_press)

    def select_folder(self):
        self.folder_path = filedialog.askdirectory()
        if self.folder_path:
            self.load_music()
            self.play_button.configure(state=tk.NORMAL)
            self.prev_button.configure(state=tk.NORMAL)
            
            self.prev_10_button.configure(state=tk.NORMAL)
            self.next_10_button.configure(state=tk.NORMAL)
            self.replay_button.configure(state=tk.NORMAL)

            #<<自動再生追加部
            self.auto_play_5_button.configure(state=tk.NORMAL)
            self.auto_play_10_button.configure(state=tk.NORMAL)
            self.auto_play_15_button.configure(state=tk.NORMAL)
            #自動再生追加部>>

            folder_name = os.path.basename(self.folder_path)
            self.folder_label.configure(text=f"{folder_name}")

    def load_music(self):
        pygame.mixer.init()
        self.music_list = [
            file
            for file in os.listdir(self.folder_path)
            if file.endswith(".mp3")
        ]

    def play_music(self):
        if self.current_index < len(self.music_list):
            music_file = os.path.join(
                self.folder_path, self.music_list[self.current_index]
            )
            pygame.mixer.music.load(music_file)
            pygame.mixer.music.play()
            self.current_file = self.music_list[self.current_index]
            self.current_file_label.configure(
                text=f"{self.current_file}"
            )
            self.current_index += 1
            self.prev_button.configure(state=tk.NORMAL)
            self.prev_10_button.configure(state=tk.NORMAL)
        else:
            self.current_index = 0
            self.play_music()

    def play_previous(self):
        if self.current_index > 0:
            self.current_index -= 2
            self.play_music()
        else:
            self.current_index = len(self.music_list) - 1
            self.play_music()

    def play_previous_10(self):
        if self.current_index > 9:
            self.current_index -= 11
            self.play_music()
        else:
            self.current_index = len(self.music_list) - 10
            self.play_music()

    def play_next(self):
        if self.current_index < len(self.music_list):
            self.play_music()
        else:
            self.current_index = 0
            self.play_music()

    def play_next_10(self):
        if self.current_index < len(self.music_list) - 9:
            self.current_index += 9
            self.play_music()
        else:
            self.current_index = 0
            self.play_music()

    def play_same(self):
        if self.current_file:
            music_file = os.path.join(self.folder_path, self.current_file)
            pygame.mixer.music.load(music_file)
            pygame.mixer.music.play()

    def play_button_press(self, event):
        self.play_music()

    def prev_button_press(self, event):
        self.play_previous()

    def prev_10_button_press(self, event):
        self.play_previous_10()
        
    def next_10_button_press(self, event):
        self.play_next_10()

    def replay_button_press(self, event):
        self.play_same()
    
    #<<自動再生追加部
    def auto_play_5(self):
        if not self.auto_play_5_flag:
            self.auto_play_5_flag = True
            self.auto_play_5_button.configure(text="停止(5秒)")
            self.auto_play_10_button.configure(state=tk.DISABLED)
            self.auto_play_15_button.configure(state=tk.DISABLED)
            self.auto_play_5_timer()
        else:
            self.auto_play_5_flag = False
            self.auto_play_5_button.configure(text="自動再生(5秒)")
            self.auto_play_10_button.configure(state=tk.NORMAL)
            self.auto_play_15_button.configure(state=tk.NORMAL)
            
    def auto_play_10(self):
        if not self.auto_play_10_flag:
            self.auto_play_10_flag = True
            self.auto_play_10_button.configure(text="停止(10秒)")
            self.auto_play_5_button.configure(state=tk.DISABLED)
            self.auto_play_15_button.configure(state=tk.DISABLED)
            self.auto_play_10_timer()
        else:
            self.auto_play_10_flag = False
            self.auto_play_10_button.configure(text="自動再生(10秒)")
            self.auto_play_5_button.configure(state=tk.NORMAL)
            self.auto_play_15_button.configure(state=tk.NORMAL)
            
    def auto_play_15(self):
        if not self.auto_play_15_flag:
            self.auto_play_15_flag = True
            self.auto_play_15_button.configure(text="停止(15秒)")
            self.auto_play_5_button.configure(state=tk.DISABLED)
            self.auto_play_10_button.configure(state=tk.DISABLED)
            self.auto_play_15_timer()
        else:
            self.auto_play_15_flag = False
            self.auto_play_15_button.configure(text="自動再生(15秒)")
            self.auto_play_5_button.configure(state=tk.NORMAL)
            self.auto_play_10_button.configure(state=tk.NORMAL)

    def auto_play_5_timer(self):
        if self.auto_play_5_flag:
            self.play_music()
            if self.current_file_label.cget("text") == "move_000.mp3":
                self.root.after(12000, self.auto_play_5_timer)
            else:
                self.root.after(6000, self.auto_play_5_timer)
       
    def auto_play_10_timer(self):
        if self.auto_play_10_flag:
            self.play_music()
            if self.current_file_label.cget("text") == "move_000.mp3":
                self.root.after(14000, self.auto_play_10_timer)
            else:
                self.root.after(11000, self.auto_play_10_timer)
                
    def auto_play_15_timer(self):
        if self.auto_play_15_flag:
            self.play_music()
            if self.current_file_label.cget("text") == "move_000.mp3":
                self.root.after(16000, self.auto_play_15_timer)
            else:
                self.root.after(16000, self.auto_play_15_timer)
            
    def stop_auto_play(self):
        self.auto_play_5_flag = False
        self.auto_play_10_flag = False
        self.auto_play_15_flag = False
        self.auto_play_5_button.configure(text="自動再生(5秒)")
        self.auto_play_10_button.configure(text="自動再生(10秒)")
        self.auto_play_15_button.configure(text="自動再生(15秒)")
        self.auto_play_5_button.configure(state=tk.NORMAL)
        self.auto_play_10_button.configure(state=tk.NORMAL)
        self.auto_play_15_button.configure(state=tk.NORMAL)
    #自動再生追加部>>


root = tk.Tk()
root.geometry("470x170")  # ウィンドウのサイズを指定
app = MusicPlayer(root)
root.mainloop()
